.. mdinclude:: _rtd/landing.md

.. toctree::
   :hidden:
   :caption: Getting Started
   :maxdepth: 4

   Home <self>
   About MIBI Pipeline <_rtd/pipeline>
   Data Type Info <_rtd/data_types>
   Developer Info <_rtd/development>
   Windows Configuration Info <_rtd/windows_setup>
   Contributing Guidelines <_rtd/contributing>
   FAQ <_rtd/faq>

.. toctree::
   :hidden:
   :caption: Modules
   :maxdepth: 4

   analysis <_markdown/ark.analysis>
   phenotyping <_markdown/ark.phenotyping>
   segmentation <_markdown/ark.segmentation>
   spLDA <_markdown/ark.spLDA>
   utils <_markdown/ark.utils>
